/*******************************************************************************
 * Copyright (c) 2009 Pascal Bodin
 * pascal dot bodin at monblocnotes dot com

This file is part of Review.

Review is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Review is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Review.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/
package com.monblocnotes.review;

import java.util.ArrayList;
import java.util.ResourceBundle;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.ShellAdapter;
import org.eclipse.swt.events.ShellEvent;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.MessageBox;
import org.eclipse.swt.widgets.Shell;

public class Review {
	
	private final static int WIDTH = 300;
	private final static int HEIGHT = 300;
	
	private static ResourceBundle resReview = ResourceBundle.getBundle("review");
	
	private Shell shell;
	
	private DataAccess dataAccess = null;
	
	ArrayList<PairInfo> pairs = null;
	
	private static final String VERSION_NUMBER = "V0.1";
	
	public static void main(String[] args) {
		Display display = new Display();
		Review application = new Review();
		Shell shell = application.open(display);
		while(!shell.isDisposed()){
			if(!display.readAndDispatch())
				display.sleep();
		}
		display.dispose();
	}

	private Shell open(Display display) {
		shell = new Shell(display);
		shell.setLayout(new FillLayout());
		shell.addShellListener(new ShellAdapter() {
			public void shellClosed(ShellEvent e) {
				e.doit = closeReview();
			}
		});
		
		// Menu setup.
		createMenuBar();

		// Initialization.
		newReview();

		//Display GUI.
		shell.setSize(WIDTH, HEIGHT);
		shell.open();

		return shell;
	}

	private Menu createMenuBar() {
		Menu menuBar = new Menu(shell, SWT.BAR);
		shell.setMenuBar(menuBar);
		
		createManageMenu(menuBar);		
		createHelpMenu(menuBar);
				
		return menuBar;
	}

	private void createManageMenu(Menu menuBar) {
		//Manage menu.
		MenuItem item = new MenuItem(menuBar, SWT.CASCADE);
		item.setText(resReview.getString("Menu_manage"));
		Menu menu = new Menu(shell, SWT.DROP_DOWN);
		item.setMenu(menu);		

		//Manage -> Words - 0
		MenuItem subItem = new MenuItem(menu, SWT.NONE);
		subItem.setText(resReview.getString("Menu_words"));
		subItem.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				manageWords();
			}
		});

		// 1
		new MenuItem(menu, SWT.SEPARATOR);
		
		//Configure -> Exit - 2
		subItem = new MenuItem(menu, SWT.NONE);
		subItem.setText(resReview.getString("Menu_exit"));
		subItem.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				shell.close();
			}
		});

	}

	private void createHelpMenu(Menu menuBar) {

		//Help Menu
		MenuItem item = new MenuItem(menuBar, SWT.CASCADE);
		item.setText(resReview.getString("Menu_help"));	
		Menu menu = new Menu(shell, SWT.DROP_DOWN);
		item.setMenu(menu);
		
		//Help -> About
		MenuItem subItem = new MenuItem(menu, SWT.NONE);
		subItem.setText(resReview.getString("Menu_about"));
		subItem.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				MessageBox box = new MessageBox(shell, SWT.NONE);
				box.setText(resReview.getString("AW_about1") + " " + VERSION_NUMBER);
				box.setMessage(resReview.getString("AW_about2"));
				box.open();		
			}
		});
	}


	private void newReview() {
		int retStatus = 0;
		
		shell.setText(resReview.getString("MW_title"));
		
		dataAccess = new DataAccess();
		retStatus = dataAccess.startDataAccess();
		if (retStatus != DataAccess.DA_SUCCESS) {
			dataAccess = null;
			return;
		}
	}

	protected void manageWords() {
		
		ManagePairsDialog managePairsDialog = new ManagePairsDialog(shell);
		managePairsDialog.prepareDialog(dataAccess, pairs);
		managePairsDialog.open();
	}

	protected boolean closeReview() {
		
		if (dataAccess != null) {
			dataAccess.stopDataAccess();
		}
					
		return true;
	}
	
}